==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebCardContentDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebCardContentDescription } from "./WebCardContentDescription";
/**
 * @hidden
 */
export let WebCardContentDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebCardContentDescriptionMetadata extends Base {
        static b(a) {
            if (WebCardContentDescriptionMetadata.a == null) {
                WebCardContentDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebCardContentDescriptionMetadata.c(WebCardContentDescriptionMetadata.a);
            }
            if (a.k(WebCardContentDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebCardContentDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:CardContent");
            a.item("__tagNameWC", "String:igc-card-content");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        }
        static d(a) {
            WebCardContentDescriptionMetadata.b(a);
            a.ac("WebCardContent", () => new WebCardContentDescription());
            a.ab("WebCardContent", WebCardContentDescriptionMetadata.a);
        }
    }
    WebCardContentDescriptionMetadata.$t = /*@__PURE__*/ markType(WebCardContentDescriptionMetadata, 'WebCardContentDescriptionMetadata');
    WebCardContentDescriptionMetadata.a = null;
    return WebCardContentDescriptionMetadata;
})();

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm2015/lib/WebCardContentDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebCardContentDescription } from "./WebCardContentDescription";
/**
 * @hidden
 */
export let WebCardContentDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebCardContentDescriptionMetadata extends Base {
        static b(a) {
            if (WebCardContentDescriptionMetadata.a == null) {
                WebCardContentDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebCardContentDescriptionMetadata.c(WebCardContentDescriptionMetadata.a);
            }
            if (a.k(WebCardContentDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebCardContentDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:CardContent");
            a.item("__tagNameWC", "String:igc-card-content");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        }
        static d(a) {
            WebCardContentDescriptionMetadata.b(a);
            a.ae("WebCardContent", () => new WebCardContentDescription());
            a.ad("WebCardContent", WebCardContentDescriptionMetadata.a);
        }
    }
    WebCardContentDescriptionMetadata.$t = /*@__PURE__*/ markType(WebCardContentDescriptionMetadata, 'WebCardContentDescriptionMetadata');
    WebCardContentDescriptionMetadata.a = null;
    return WebCardContentDescriptionMetadata;
})();
